The `media-types` package
=========================

This package distributes the file `/etc/mime.types`.  It is needed mainly by
applications identifying a file's [media type](https://tools.ietf.org/html/rfc6838)
by its filename's extension.  For instance, several web servers reverse depend
on it.  A large number of packages [mention `/etc/mime.types` in their
sources](http://codesearch.debian.net/search?q=%2Fetc%2Fmime.types+&literal=1)

Non-maintainer uploads
----------------------

In principle, please ask before uploading this package.  If a change is urgent
and you are Debian developer, consider a _Team upload_, so that you can
follow the semantic versioning scheme described below.

Semantic versioning
--------------------

The version number of this package follows the [semantic versionning](https://semver.org/)
scheme.  Update the _MAJOR_ number when removing a media type or changing the number of
occurrences of a filename extension.  Update the _MINOR_ number when adding a new
type or filename extension.  Update the _PATCH_ number for other changes.

The IANA folder in the source tree
----------------------------------

contains a copy of the information on the IANA's website at the time I
synchronise from it.

Survey of duplicated file extensions
------------------------------------

In principle, having the same file extension multiple times in
`/etc/mime.types` can create uncertainty on what media type will be selected
for a file.  The following oneliner sorts the file extensions by the times they
occur.

    grep -v \# mime.types | awk '{$1=""; print}'| perl -pe 's/(\s)+/\n/g' |  sed '/^$/d' | sort | uniq -c | sort -n

In some cases, it is unavailable.

### File extensions for media types listed as both `text/` and `application/`

 - Script languages such as `sh`, `csh`, `tcl`.

### File extensions used in unrelated media types

 - `sdf` is used in `application/vnd.Kinar` and `application/vnd.stardivision.math`.
   The _stardivision_ types are not listed at the IANA.  It it time to remove them?

 - `omg` is listed in all three ATRAC media types.  Is there a reasonable default?

### Unclear cases

 - `otf` and `ttf` font extensions.


Misc. notes
-----------

## List tab-separated types and subtypes from `mime.types`.

    perl -nE 'next if /^#|^ |^$/ ; say join "\t", (split m,/|\s,)[0,1]' mime.types

## List types and subtypes from the FreeDesktop shared-mime-info project.

    wget http://cgit.freedesktop.org/xdg/shared-mime-info/plain/freedesktop.org.xml.in
    vi freedesktop.org.xml.in  # edit by removing DOCTYPE, removing the <?xml line
                                 and removing the xmlns attribute in the mime-info tag.
    cat freedesktop.org.xml.in |
      xmlstarlet sel -T -t -m "mime-info" \
                           -m "mime-type" -v "@type" -o "$(printf "\t")" \
                           -m "glob" -v "@pattern" -o " " -b -nl |
      sed 's/\*\.//g'

## To do ?

 - Test at build time that there are no duplicated media types in `mime.types`.

## To check for IANA `image` media types that are not yet in `mime.types`

 - wget https://www.iana.org/assignments/media-types/image.csv
 - sed 1d image.csv | cut -f2 -d, | sed '/^$/d' | grep -f - mime.types | cut -f 1 | grep -f - -v image.csv

## Draft oneliner to add lines between content types

 - perl -F/ -ne 'print "\n" if $prev ne $F[0] ; print ; $prev = $F[0]' mime.types
